@@ -1,4 +1,9 @@
+#
+# Copyright (C) 2020 IHS Markit.
+# All Rights Reserved
+#
 import inspect
+from functools import wraps
 
 
 class LoggingAspect:
@@ -97,6 +102,7 @@ class AnalyticsAspect:
 def analytics_decorator(function, class_fields_to_include):
     aspect = AnalyticsAspect()
 
+    @wraps(function)
     def function_wrapper(target, *args, **kwargs):
         metadata = extract_metadata(
             target._client, target, function, args, kwargs, class_fields_to_include
@@ -117,6 +123,7 @@ def analytics_decorator(function, class_fields_to_include):
 def logging_decorator(function, class_fields_to_include):
     aspect = LoggingAspect()
 
+    @wraps(function)
     def function_wrapper(target, *args, **kwargs):
         metadata = extract_metadata(
             target._client, target, function, args, kwargs, class_fields_to_include
