@@ -3,10 +3,10 @@
 # All Rights Reserved
 #
 #import pyshorteners
+import base64
 import datetime
 import os
 import sys
-import threading
 import time
 import webbrowser
 from json import JSONDecodeError
@@ -23,11 +23,10 @@ from http.cookiejar import CookiePolicy
 # import webview
 from wrapt import ObjectProxy
 from http import HTTPStatus
-from urllib.parse import urljoin, urlparse, parse_qs, urlencode
+from urllib.parse import urljoin, urlparse, parse_qs
 from collections import defaultdict
 from dli import __version__, __product__
 from dli.analytics import AnalyticsHandler
-from dli.client.listener import _Listener, can_launch
 from dli.client.adapters import DLIBearerAuthAdapter, DLIAccountsV1Adapter, \
     DLIInterfaceV1Adapter, DLISamAdapter
 from dli.client.components.urls import sam_urls, identity_urls
@@ -39,7 +38,6 @@ from dli.client.components.datafile import Datafile
 from dli.client.components.dataset import Dataset, Dictionary
 from dli.client.components.me import Me
 from dli.client.components.package import Package
-from dli.client.components.search import Search
 from dli.client.components.accounts import Accounts
 from dli.client.exceptions import (
     DatalakeException, InsufficientPrivilegesException,
@@ -93,7 +91,7 @@ class ModelDescriptor:
 
 class DliClient(Accounts, AutoRegMetadata,
                 Datafile, Dataset, Dictionary,
-                Me, Package, Search):
+                Me, Package):
     """
     Definition of a client. This client mixes in utility functions for
     manipulating packages, datasets and datafiles.
@@ -220,14 +218,14 @@ class Session(requests.Session):
         # disable the use of keyring
         self.use_keyring = False
         print(
-            f"We've noticed that you seem to be trying to run the SDK in a "
-            f"headless machine but your application credential "
-            f" environment variables (DLI_ACCESS_KEY_ID and "
-            f"DLI_SECRET_ACCESS_KEY) "
-            f" aren't set or there is no keyring manager available.\n\n"
-            f"YOU MAY NEED TO LOGIN EVERY TIME.\n"
-            f"Please contact support at datalake-support@ihsmarkit.com.\n"
-            f"{str(nke)}"
+            "We have noticed you are trying to run the SDK on a headless "
+            "machine but your application credential environment variables "
+            "(DLI_ACCESS_KEY_ID and DLI_SECRET_ACCESS_KEY) "
+            "are not set or there is no keyring manager available. \n\n"
+            f"YOU MAY NEED TO LOGIN EVERY TIME. \n"
+            f"Please contact support at datalake-support@ihsmarkit.com"
+            f"if you need more help. \n\n"
+            f"{str(nke)}\n\n"
         )
         if raises:
             raise nke
@@ -301,7 +299,6 @@ class Session(requests.Session):
         return timeout
 
     def request(self, method, url, *args, **kwargs):
-
         if not urlparse(url).netloc:
             url = urljoin(self._environment.catalogue, url)
 
@@ -498,141 +495,86 @@ class Session(requests.Session):
 
     def _get_web_auth_key(self, callback=None):
 
-        result, reason = can_launch(_Listener.DEFAULT_PORT)
-        if not result:
-
-            if not reason.startswith("[Errno 98]"):
-                # we cannot simply raise, since another SDK may be blocking 8080
-                # (98 already in use)
-                # and be usable - but we can raise if we get a refusal
-                # (111 connection refused)
-                raise Exception(f"Cannot authenticate via user flow. Contact DL-Support"
-                                f" or your system administrator.\nThis occurred because"
-                                f" whilst trying to start the callback listener at"
-                                f" {_Listener.LOCALHOST}:{_Listener.DEFAULT_PORT}.\n"
-                                f"We received {reason} from the socket. This may indicate"
-                                f" the socket is already in use or your firewall is"
-                                f" blocking inbound connections.")
-            else:
-                # so we need to just hit it first, to see if it replies as expected
-                try:
-                    query = requests.get(
-                        f"{_Listener.LOCALHOST}:{_Listener.DEFAULT_PORT}" \
-                        f"/get/test")
-
-                    if query.status_code != 404 or \
-                            "jwt" not in query.json().keys() or \
-                            query.json()["jwt"] != "None":
-                        raise Exception(
-                            f"Cannot authenticate via user flow. Contact DL-Support"
-                            f" or your system administrator.\nThis occurred because"
-                            f" whilst trying to contact the callback listener at"
-                            f" {_Listener.LOCALHOST}:{_Listener.DEFAULT_PORT}.\n"
-                            f"We received {reason} from the socket. This may indicate"
-                            f" the socket is already in use (and not by another SDK"
-                            f" instance or your firewall is blocking inbound "
-                            f"connections.")
-                    else:
-                        result = True
-                except requests.ConnectionError as e:
-                    # may not even be up
-                    result = True
-
-        postbox = _Listener.run(_Listener.DEFAULT_PORT)
-        time.sleep(1)
-        # we may need a little time to start the instance in
-        # some systems - else we request /get before started
+        postbox = base64.urlsafe_b64encode(uuid.uuid4().bytes)\
+            .decode('utf-8').replace('=', '')
+        str_jwt = None
 
         if callback is None:
-            url = f"{_Listener.LOCALHOST}:{_Listener.DEFAULT_PORT}" \
-                  f"/login?postbox={postbox}&{urlencode(self._environment.__dict__)}"
+            url = f"{self._environment.catalogue}" \
+                  f"{identity_urls.identity_postbox}" \
+                  f"?postbox={postbox}&" \
+                  f"target=/api/identity/v2/auth/postbox_confirmation"
             # we need to check that the listener can actually listen
             # before we open the browser - so establish that a listener
             # is up and running, or can listen (not firewalled)
             # else we need to tell the user that their firewall is shut.
+
             isopen=webbrowser.open(url, new=1)
-
             if not isopen:
-                print(f"WARNING: We couldn't open a usable browser for you to authenticate.\n"
-                      f"Please copy the below:\n\n{url}\n\nEnter this into a web browser that you can access.\n"
-                      f"If you have no browser - then you can use your phone or another machine. "
-                      f"After you do this, returning here and you will see this console un-blocked.\n"
-                      f"If you wish to abort enter Ctrl/Cmd + C on your keyboard.")
-
-            # implement this instead if SAM changes made
-            # as we can close the window once value captured.
-            # window = webview.create_window(
-            #     'Login', f"http://localhost:{_Listener.DEFAULT_PORT}/login",
-            #     resizable=False
-            # )
-            #
-            # def get_elements(window):
-            #     heading = window.get_elements('#emailaddress')
-            #
-            #     if not heading:
-            #         window = webview.create_window(
-            #             'Login', f"https://catalogue-dev.udpmarkit.net/login",
-            #             resizable=False
-            #         )
-            #         webview.start(get_elements, window, debug=False)
-            #
-            #
-            # webview.start(get_elements, window, debug=False)
-
+                print(f"WARNING: We could not open a usable web browser for authentication purposes, or alternatively,"
+                      f"Please copy the below:\n\n{url}\n\nEnter this into a web browser that you can access, "
+                      f"or alternatively, you can use your phone or a web browser on another machine. "
+                      f"After this step, by returning here, you will see this console un-blocked.\n"
+                      f"If you wish to abort enter Ctrl/Cmd + C on your keyboard.\n\n")
         else:
-            callback(_Listener.DEFAULT_PORT, postbox)
+            callback(0, postbox)
 
-        if result:
-            while True:
-                query = requests.get(f"{_Listener.LOCALHOST}:{_Listener.DEFAULT_PORT}" \
-                      f"/get/{postbox}")
-                if query.status_code != 200:
+        while True:
+            try:
+                query = self.get(
+                    f"{self._environment.catalogue}"
+                    f"{identity_urls.identity_poll}"
+                    f"?postbox={postbox}")
+
+                if query.ok:
+                    str_jwt = query.text
+                    _jwt = str.encode(str_jwt)
+                    break
+
+            except DatalakeException as e:
+                # anti-pattern time - to be able to patch session appropriately
+                # i need to modify the get, but the responsehook sees the 404
+                # prior to the above logic
+                if e.response.status_code == 404 or e.response.status_code == 409:
                     time.sleep(0.5)
-                else:
-                    str_jwt = query.json()["jwt"]
-                    if str_jwt != "invalid":
-                        _jwt = str.encode(str_jwt)
-                        break
-                    else:
-                        print("You have another SDK login open. Complete that first.")
-                        sys.exit(0)
+                elif e.response.status_code == 401:
+                    print("We couldn't log you in. A problem was encountered\n"
+                          "If this issue persists please contact DL-Support")
+                    sys.exit(0)
 
+        if str_jwt and hasattr(self, "use_keyring") and self.use_keyring:
+            try:
+                keyring.set_password(__product__, self._environment.catalogue,
+                                     str_jwt)
+            except (Exception, OSError) as e:
+                # length issue on Windows > 1280 chars in Windows Credentials
+                if os.name == 'nt':
+                    lens = 1000
+                    chunks = [
+                        str_jwt[i:i + lens]
+                        for i in range(0, len(str_jwt), lens)
+                    ]
+                    try:
+                        # index
+                        keyring.set_password(
+                            __product__,
+                            self._environment.catalogue,
+                            f"**split**{len(chunks)}"
+                        )
 
-            if hasattr(self, "use_keyring") and self.use_keyring:
-                try:
-                    keyring.set_password(__product__, self._environment.catalogue, str_jwt)
-                except (Exception, OSError) as e:
-                    # length issue on Windows > 1280 chars in Windows Credentials
-                    if os.name == 'nt':
-                        lens = 1000
-                        chunks = [
-                            str_jwt[i:i + lens]
-                            for i in range(0, len(str_jwt), lens)
-                        ]
-                        try:
-                            # index
+                        # segments
+                        for ix, chunk in enumerate(chunks):
                             keyring.set_password(
                                 __product__,
-                                self._environment.catalogue,
-                                f"**split**{len(chunks)}"
+                                self._environment.catalogue + f"-{ix}",
+                                chunk
                             )
-
-                            # segments
-                            for ix, chunk in enumerate(chunks):
-                                keyring.set_password(
-                                    __product__,
-                                    self._environment.catalogue + f"-{ix}",
-                                    chunk
-                                )
-                        except Exception as e:
-                            logging.warning(str(e))
-                    else:
+                    except Exception as e:
                         logging.warning(str(e))
-
-            # cleanup
-            requests.post(f"{_Listener.LOCALHOST}:{_Listener.DEFAULT_PORT}/shutdown")
-            # window.destroy()
-            return str_jwt
+                else:
+                    logging.warning(str(e))
+        # import pdb; pdb.set_trace()
+        return str_jwt
 
 
 class Response(ObjectProxy):
