@@ -32,18 +32,25 @@ class DatalakeException(Exception):
             error += (
                 f'{json.dumps(self.response.json(), indent=4)}'
             )
+
         except json.JSONDecodeError:
             error += (
                 f'{self.response.text}'
             )
 
-        request_id = self.response.request.headers.get(
-            'X-Request-ID', 'unknown'
-        )
 
-        error += (
+        try:
+            request_id = self.response.request.headers.get(
+                'X-Request-ID', 'unknown'
+            )
+
+            error += (
                 f'\nProvided request_id: {request_id}\n'
-        )
+            )
+        except Exception:
+            error += (
+                f'\nProvided request_id: Unknown\n'
+            )
 
         return error
 
