@@ -9,10 +9,10 @@ import uuid
 import warnings
 import pandas
 import pyarrow
-import boto3
 
 from typing import List, Optional
 from urllib.parse import urljoin
+
 from tabulate import tabulate
 from s3transfer.manager import TransferManager
 
@@ -138,7 +138,6 @@ class DatasetModel(AttributesDict):
                 }
             )
 
-
     def download(
         self, 
         destination_path: str,
@@ -162,7 +161,8 @@ class DatasetModel(AttributesDict):
             will be downloaded
 
 
-        :return: the list of the downloaded files
+        :return: the list of the files that were downloaded successfully. Any
+            failures will be printed.
 
 
         :example:
@@ -241,7 +241,7 @@ class DatasetModel(AttributesDict):
                 self.organisation_short_code
             )
 
-            _paths = []
+            _paths_and_futures = []
 
             filter_prefix = self.short_code + (
                     '' if self.short_code.endswith('/') else '/'
@@ -262,7 +262,9 @@ class DatasetModel(AttributesDict):
                         flatten=flatten
                     )
 
-                    print(f'Downloading {object_summary.key} to: {to_path}...')
+                    self._client.logger.info(
+                        f'Downloading {object_summary.key} to: {to_path}...'
+                    )
 
                     if os.path.exists(to_path):
                         warnings.warn(
@@ -270,15 +272,30 @@ class DatasetModel(AttributesDict):
                         )
 
                     # returns a future
-                    transfer_manager.download(
+                    future = transfer_manager.download(
                         self.organisation_short_code,
                         object_summary.key,
                         to_path
                     )
 
-                    _paths.append(to_path)
+                    _paths_and_futures.append((to_path, future))
 
-            return _paths
+            _successful_paths = []
+            for path, future in _paths_and_futures:
+                try:
+                    # This will block for this future to complete, but other
+                    # futures will keep running in the background.
+                    future.result()
+                    _successful_paths.append(path)
+                except Exception as e:
+                    message = f'Problem while downloading:' \
+                        f'\nfile path: {path}'\
+                        f'\nError message: {e}\n\n'
+
+                    self._client.logger.error(message)
+                    print(message)
+
+            return _successful_paths
 
     def _dataframe(self, nrows=None, partitions: List[str] = None, raise_=True):
         warnings.warn(
