@@ -1,3 +1,6 @@
+from contextlib import redirect_stdout
+from functools import partial
+
 import pytest
 import copy
 import os
@@ -9,65 +12,14 @@ import pandas
 import numpy
 import random
 import json
+import jwt
 
-from dli.client.exceptions import DataframeStreamingException
+from contextlib import redirect_stdout
+from tests.integration.conftest import TestDliClient
+from dli.client.exceptions import DataframeStreamingException, TimeoutException
 from unittest.mock import MagicMock, ANY
 
-
-def test_display_dataset(capsys, test_client, package_request,
-                         package_request_v2, dataset_request_index, 
-                         instance_request):
-    test_client._session.get.return_value.json.side_effect = [
-        package_request, package_request_v2,
-        dataset_request_index, instance_request,
-    ]
-
-    pp = test_client.packages(search_term="", only_mine=False)
-    ds = pp["Test Package"].datasets()
-    d = ds["Test DataSet"]
-    d.contents()
-    captured = capsys.readouterr()
-    assert captured.out == "\nINSTANCE 1\n"
-
-
-def test_retrieve_datasets(test_client, dataset_request_v1, dataset_request):
-    test_client._session.get.return_value.json.side_effect = [
-        dataset_request_v1, dataset_request
-    ]
-
-    # calls in the same way as package
-    pp = test_client.datasets(search_term="", only_mine=False)
-    assert len(pp) == 1
-
-
-def test_datasets_called_twice(test_client, package_request,
-                               package_request_v2, dataset_request_index):
-
-    test_client._session.get.return_value.json.side_effect = [
-        package_request, package_request_v2, dataset_request_index
-    ]
-    pp = test_client.packages(search_term="", only_mine=False)
-
-    #this should work twice
-    storm_datasets = pp["Test Package"].datasets()
-    storm_datasets = pp["Test Package"].datasets()
-
-
-def test_retrieve_instance_given_package_dataset(test_client,
-     package_request, package_request_v2,
-     dataset_request_index, instance_request
-):
-    test_client._session.get.return_value.json.side_effect = [
-        package_request, package_request_v2,
-        dataset_request_index, instance_request,
-    ]
-
-    pp = test_client.packages(search_term="", only_mine=False)
-    ds = pp["Test Package"].datasets()
-    d = ds["Test DataSet"]
-    instances = list(d.instances.all())
-    assert(len(instances) == 1)
-    assert(instances[0].datafile_id == 1)
+from tests.models.conftest import mock_catalogue_filter_search_response_impl
 
 
 @pytest.fixture
@@ -75,7 +27,8 @@ def instance_file(client):
     client._environment.consumption = 'consumption-test.local'
 
     instance = client.Instance(
-        datafile_id='123'
+        datafile_id='123',
+        total_size=1048576
     )
 
     client._session.get().json.return_value = {
@@ -102,6 +55,31 @@ def instance_file(client):
 
 class TestDataset:
 
+    def test_timeout_error_hook_after_get_dataset(self, monkeypatch):
+        # mock client targeted at url with valid host but invalid port.
+        # instead of TestClientMock that would mock the whole session but
+        # we only need to mock the jwt auth - mock_hasexpired=False
+
+        secret = 'secret'
+        client = TestDliClient(
+            api_root='https://google.com:65531/__api_v2',
+            auth_key=jwt.encode(payload={},
+                                key=secret),
+            host='https://google.com:65531',
+            debug=False,
+            jwt=None,
+            secret=secret,
+            access_id='noop',
+            secret_key='noop'
+        )
+
+        monkeypatch.setattr(
+            'dli.client.dli_client.Session._get_timeout',
+            MagicMock(return_value=0.001))
+
+        with pytest.raises(TimeoutException):
+            client.get_dataset(dataset_short_code='timeout_dataset')
+
     def test_dataset_instances_is_iterable(self, client):
         dataset = client.Dataset._from_v2_response({
             'data': {
@@ -217,15 +195,58 @@ class TestDataset:
         assert(len(dataset.instances._paginator.cache) == 3)
         assert(len(instances_from_cache) == 3)
 
-    def test_dataset_is_wrapped_with_analytics_logger(self, client,
-                                                      instance_file):
+    def test_dataset_filter_prefix(self, client, monkeypatch, instance_file):
+        boto_mock = MagicMock()
+        monkeypatch.setattr(
+            'dli.models.dataset_model.create_refreshing_session',
+            boto_mock
+        )
+
         dataset = client.Dataset._from_v2_response({
-            'data': {'id': '1234', 'attributes': {'location': {}, }}
+            'data': {
+                'id': '1234',
+                'attributes': {
+                    'location': {},
+                    'organisation_short_code': 'abc',
+                    'short_code': 'abc',
+                    'has_access': True,
+                }
+            }
         })
 
-        dataset.instances.latest = MagicMock(
-            return_value=client.Instance(datafile_id='123')
-        )
+        with tempfile.TemporaryDirectory() as target_dest:
+            dataset.download(target_dest)
+
+        assert (
+            boto_mock().resource().Bucket()
+            .objects.filter.call_args[1]['Prefix']
+        ) == 'abc/'
+
+        with tempfile.TemporaryDirectory() as target_dest:
+            dataset.download(target_dest, filter_path='/123')
+
+        assert (
+            boto_mock().resource().Bucket()
+            .objects.filter.call_args[1]['Prefix']
+        ) == 'abc/123'
+
+    def test_dataset_is_wrapped_with_analytics_logger(self, client,
+                                                      monkeypatch,
+                                                      instance_file):
+        boto_mock = MagicMock()
+        monkeypatch.setattr('dli.aws.Session', boto_mock)
+
+        dataset = client.Dataset._from_v2_response({
+            'data': {
+                'id': '1234',
+                'attributes': {
+                    'location': {},
+                    'organisation_short_code': 'abc',
+                    'short_code': 'abc',
+                    'has_access': True,
+                }
+            }
+        })
 
         with tempfile.TemporaryDirectory() as target_dest:
             dataset.download(target_dest)
@@ -243,6 +264,35 @@ class TestDataset:
             },
             result_status_code=200
         )
+    def test_dataset_info(self, test_client, dataset_request_v2,
+                          dictionary_request_v2, fields_request_v2):
+        test_client.session.reset_mock()
+        test_client._session.get.return_value.json.side_effect = [
+            dictionary_request_v2, fields_request_v2
+        ]
+
+        dataset = test_client.Dataset._from_v2_response(dataset_request_v2)
+
+        def redirect(fun):
+            with io.StringIO() as buf, redirect_stdout(buf):
+                fun()
+                output = buf.getvalue()
+                return output
+
+
+        assert(
+            redirect(dataset.info)
+                .replace(" ", "").replace("\n", "")
+               ==
+            """
+                name    type
+                ------  -----------------
+                col1    String (Nullable)
+                col2    String (Nullable)
+                col3    String
+            """
+                .replace(" ", "").replace("\n", "")
+        )
 
 
 class TestFileDownload:
@@ -336,33 +386,23 @@ class TestInstanceDownload:
 
     def test_instance_download_all_should_refer_to_download_function(self, instance):
         path = './target'
-        instance.download = Mock(return_value='file')
-        result = instance.download_all(path)
+        instance.download = MagicMock(return_value='file')
+        result = instance.download_all(path, flatten=False)
 
-        instance.download.assert_called_once_with(path)
+        instance.download.assert_called_once_with(path, False)
         assert result == 'file'
 
-    def test_instance_download(self, client, monkeypatch, instance):
-        client._session.get().raw = io.BytesIO(b'abc')
-
-        with tempfile.TemporaryDirectory() as target_dest:
-            target_dest = os.path.join(target_dest, 'a')
-            instance.download_all(target_dest)
-
-            assert (
-                sorted(os.listdir(os.path.join(target_dest, 'prefix'))) ==
-                ['test.000.csv', 'test.001.csv', 'test.002.csv']
-            )
-
     def test_instance_download_flatten(self, client, monkeypatch, instance):
         client._session.get().raw = io.BytesIO(b'abc')
 
         with tempfile.TemporaryDirectory() as target_dest:
-            target_dest = os.path.join(target_dest, 'a')
-            instance.download(to=target_dest, flatten=True)
+            to = os.path.join(target_dest, 'a')
+            result = instance.download_all(to, flatten=True)
+            directory_of_flattened = result[0].split('/test')[0]
+            list_dir = sorted(os.listdir(directory_of_flattened))
 
             assert (
-                sorted(os.listdir(target_dest)) ==
+                list_dir ==
                 ['test.000.csv', 'test.001.csv', 'test.002.csv']
             )
 
@@ -370,7 +410,7 @@ class TestInstanceDownload:
 class TestInstanceDataframe:
 
     @pytest.fixture
-    def test_dataframe(self) -> pandas.DataFrame:
+    def arrow_ipc_stream(self) -> (pandas.DataFrame, io.BytesIO):
         # Rows:
         # 100 -> 205.5 kB (205,548 bytes) on disk in 0.44 seconds.
         # 10000 -> 9.2 MB (9,234,131 bytes) on disk in 0.67 seconds.
@@ -469,17 +509,13 @@ class TestInstanceDataframe:
         assert df.shape[0] == max_rows
         assert df.shape[1] == max_columns
 
-        return df
-
-    @pytest.fixture
-    def arrow_ipc_stream(self, test_dataframe):
         sink = pyarrow.BufferOutputStream()
-        batch = pyarrow.RecordBatch.from_pandas(test_dataframe)
+        batch = pyarrow.RecordBatch.from_pandas(df, nthreads=1)
         writer = pyarrow.RecordBatchStreamWriter(sink, batch.schema)
         writer.write_batch(batch)
         # It's important the IPC stream is closed
         writer.close()
-        return io.BytesIO(sink.getvalue().to_pybytes())
+        return df, io.BytesIO(sink.getvalue().to_pybytes())
 
     @pytest.fixture
     def dataset(self, client):
@@ -488,35 +524,43 @@ class TestInstanceDataframe:
                 'id': '1234',
                 'attributes': {
                     'location': {},
+                    'has_access': True,
+                    'short_code': 'some-short-code',
                 }
             }
         })
 
     def test_dataset_dataframe(self, benchmark, client, arrow_ipc_stream,
-                               test_dataframe, dataset):
+                               dataset):
 
+        test_dataframe, stream = arrow_ipc_stream
         dataset._client = MagicMock()
         dataset._client._environment.consumption = 'https://test/'
-        dataset._client.session.get().raw = arrow_ipc_stream
+        dataset._client.session.get().raw = stream
         dataset._client.session.get().status_code = 200
 
         def _bench():
             # reset our fake socket
-            arrow_ipc_stream.seek(0)
+            stream.seek(0)
             return dataset.dataframe()
 
         # The benchmark code will run several times to get an average runtime.
         df = benchmark(_bench)
 
         # Check that we can read from the file that was written.
+        print('test_dataframe')
+        print(test_dataframe.head(4).values)
+        print('df')
+        print(df.head(4).values)
         pandas.testing.assert_frame_equal(test_dataframe, df)
 
     @pytest.mark.parametrize('value', ['1', 0])
     def test_dataframe_nrows_validation(self, client, arrow_ipc_stream,
-                                        test_dataframe, value, dataset):
+                                        value, dataset):
+        test_dataframe, stream = arrow_ipc_stream
         dataset._client = MagicMock()
         dataset._client._environment.consumption = 'https://test/'
-        dataset._client.session.get().raw = arrow_ipc_stream
+        dataset._client.session.get().raw = stream
         dataset._client.session.get().status_code = 200
 
         # Expected to pass.
@@ -526,10 +570,16 @@ class TestInstanceDataframe:
 
     @pytest.fixture
     def partitions(self):
-        return json.dumps({
-            'a': ['c', 'd'],
-            'b': ['e', 'f', 'g']
-        })
+        return {
+            'data':{
+                'attributes': {
+                    'partitions': {
+                        'a': ["1", "2", "3"],
+                        'b': ["4", "5", "6"]
+                    }
+                }
+            }
+        }
 
     def test_dataset_partitions(self, client, partitions):
         dataset = client.Dataset._from_v2_response({
@@ -541,205 +591,207 @@ class TestInstanceDataframe:
             }
         })
 
-        dataset._client = MagicMock()
-        dataset._client._environment.consumption = 'https://test/'
-        dataset._client.session.get().status_code = 200
-        dataset._client.session.get().content = partitions
+        dataset._client = client
+        dataset._client._session.get.return_value.json.side_effect = [partitions, {
+            'data': {
+                'id': '1234',
+                'attributes': {
+                    'location': {},
+                }
+            }
+        },  partitions]
 
         msg = dataset.partitions()
-        assert(msg == json.loads(partitions))
+        assert(msg == partitions["data"]["attributes"]["partitions"])
+
+        msg = client.get_dataset_partitions(id=dataset.id)
+        assert(msg == partitions["data"]["attributes"]["partitions"])
+
 
     def test_dataframe_handle_errors(self, client, arrow_ipc_stream,
-                                     test_dataframe, dataset):
+                                     dataset):
+        test_dataframe, stream = arrow_ipc_stream
         error_msg = json.dumps({
             'status': 400,
         }).encode('utf')
 
-        arrow_ipc_stream.seek(0, 2)
-        arrow_ipc_stream.write(error_msg)
-        arrow_ipc_stream.seek(0)
+        stream.seek(0, 2)
+        stream.write(error_msg)
+        stream.seek(0)
 
         dataset._client = MagicMock()
         dataset._client._environment.consumption = 'https://test/'
-        dataset._client.session.get().raw = arrow_ipc_stream
+        dataset._client.session.get().raw = stream
         dataset._client.session.get().status_code = 200
 
         with pytest.raises(DataframeStreamingException):
             dataset.dataframe(1)
 
 
-class TestFileDownload:
-
-    def test_instance_file_download_simple(self, client, instance_file):
-        old_dir = os.path.abspath(os.curdir)
-
-        with tempfile.TemporaryDirectory() as target_dest:
-            os.chdir(os.path.abspath(target_dest))
-            instance_file.download()
-            with open(os.path.join(target_dest, 'prefix/test.001.csv')) as f:
-                assert f.read() == 'hello world'
-
-        os.chdir(old_dir)
-
-    def test_instance_file_download_with_path(self, client, instance_file):
-        with tempfile.TemporaryDirectory() as target_dest:
-            instance_file.download(target_dest)
-            with open(os.path.join(target_dest, 'prefix/test.001.csv')) as f:
-                assert f.read() == 'hello world'
-
-    def test_instance_file_download_non_existent_path(
-        self, client, instance_file
-    ):
-        with tempfile.TemporaryDirectory() as target_dest:
-            target_dest = os.path.join(target_dest, 'a/b/c/')
-            instance_file.download(target_dest)
-            with open(os.path.join(
-                target_dest, 'prefix/test.001.csv'
-            )) as f:
-                assert f.read() == 'hello world'
-
-    def test_instance_file_download_non_existent_file(
-        self, client, instance_file
-    ):
-        with tempfile.TemporaryDirectory() as target_dest:
-            target_dest = os.path.join(target_dest, 'a')
-            instance_file.download(target_dest)
-            with open(os.path.join(
-                target_dest, 'prefix/test.001.csv'
-            )) as f:
-                assert f.read() == 'hello world'
-
-    def test_instance_file_overwrites(
-        self, client, instance_file
-    ):
-        with tempfile.TemporaryDirectory() as target_dest:
-            target_dest = os.path.join(target_dest, 'a')
-            instance_file.download(target_dest)
-            with open(os.path.join(
-                target_dest, 'prefix/test.001.csv'
-            )) as f:
-                assert f.read() == 'hello world'
-
-        client.session.reset_mock()
-        client._session.get().raw.read.side_effect = [
-            b'brave new world',
-            b''
-        ]
-
-        with tempfile.TemporaryDirectory() as target_dest:
-            target_dest = os.path.join(target_dest, 'a')
-            instance_file.download(target_dest)
-            with open(os.path.join(
-                target_dest, 'prefix/test.001.csv'
-            )) as f:
-                assert f.read() == 'brave new world'
-
-
-class TestInstanceDownload:
-
-    @pytest.fixture
-    def instance(self, client):
-        client._environment.consumption = 'consumption-test.local'
-
-        instance = client.Instance(
-            datafile_id='123'
-        )
-
-        client._session.get().json.return_value = {
-            'data': [{
-                'attributes': {
-                    'path': f's3://bucket/prefix/test.00{i}.csv',
-                    'metadata': {}
-                }
-            } for i in range(3)
-            ]
-        }
-
-        yield instance
-
-    def test_instance_download_all_should_refer_to_download_function(
-        self, instance
-    ):
-        path = './target'
-        instance.download = MagicMock(return_value='file')
-        result = instance.download_all(path)
-
-        instance.download.assert_called_once_with(path)
-        assert result == 'file'
-
-    def test_instance_download(self, client, monkeypatch, instance):
-        client._session.get().raw = io.BytesIO(b'abc')
-
-        with tempfile.TemporaryDirectory() as target_dest:
-            target_dest = os.path.join(target_dest, 'a')
-            instance.download_all(target_dest)
-
-            assert sorted(os.listdir(os.path.join(target_dest, 'prefix'))) == [
-                'test.000.csv', 'test.001.csv', 'test.002.csv'
-            ]
-
-
 class TestDatasetModule:
-    def test_display_dataset(
-            self, capsys, test_client, dataset_request_index, instance_request
-    ):
+
+    def test_dataset_contents(self, capsys, test_client,
+                              package_request_index_v2, dataset_request_index_v2,
+                              instance_request_v1):
         test_client._session.get.return_value.json.side_effect = [
-            instance_request,
+            package_request_index_v2,
+            dataset_request_index_v2, instance_request_v1,
         ]
 
-        d = test_client.Dataset(
-            dataset_id='1',**dataset_request_index['data'][0]
-        )
-
+        pp = test_client.packages(search_term='', only_mine=False)
+        ds = pp['Test Package'].datasets()
+        d = ds['TestDataset']
         d.contents()
         captured = capsys.readouterr()
-        assert captured.out == '\nINSTANCE 1\n'
+        assert captured.out == '\nINSTANCE 1 (size: 1.00 Mb)\n'
 
-    def test_retrieve_datasets(self, test_client, dataset_request_v1):
+    @pytest.fixture()
+    def return_value(self, dataset_request_index_v2):
+        return partial(
+            mock_catalogue_filter_search_response_impl,
+            dataset_request_index_v2
+        )
+
+    def test_find_no_params(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets()) == 2
+
+    def test_find_datasets_no_list(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(search_term=[])) == 2
+
+    def test_find_datasets_all_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(only_mine=False)) == 2
+
+    def test_find_datasets_only_mine(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(only_mine=True)) == 1
+
+    def test_find_datasets_no_search_all_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(search_term=None, only_mine=False)) == 2
+
+    def test_find_datasets_no_list_all_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(search_term=[], only_mine=False)) == 2
+
+    def test_find_datasets_no_term_only_mine(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(search_term=None, only_mine=True)) == 1
+
+    def test_find_datasets_no_list_only_mine(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(search_term=[], only_mine=True)) == 1
+
+    def test_find_datasets_ignore_bad_data_list(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term=["baddata"], only_mine=False)) == 2
+
+    def test_find_datasets_ignore_multi_bad_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term=["baddata", "baddata"], only_mine=False)) == 2
+
+    def test_find_datasets_ignore_bad_keep_good_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term=["short_code=TestDataset", "baddata"], only_mine=False)) == 1
+
+    def test_find_datasets_ignore_bad_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term="baddata", only_mine=False)) == 2
+
+    def test_find_datasets_name_search_match(self, test_client, return_value):
+        test_client._session.get = return_value
+        # testing search term with only_mine param against valid search term
+        assert len(test_client.datasets(
+            search_term=["short_code=TestDataset"], only_mine=False)) == 1
+
+    def test_find_datasets_no_search_my_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term=[], only_mine=True)) == 1
+
+    def test_find_datasets_no_match(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term=["short_code=NotTestDataset"], only_mine=True)) == 0
+
+    def test_find_datasets_multi_param_my_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        # multi-param against only_mine
+        assert len(test_client.datasets(
+            search_term=["name=Other Dataset"],
+            only_mine=True)) == 0
+
+    def test_find_datasets_multi_param_all_data(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term=["name=Test DataSet", "description=description",
+                         "organisation_name=IHS Markit"],
+            only_mine=False)) == 1
+
+    def test_find_datasets_find_both(self, test_client, return_value):
+        test_client._session.get = return_value
+        assert len(test_client.datasets(
+            search_term=["description=description"],
+            only_mine=False)) == 2
+
+    def test_find_datasets_multi_param_no_match(self, test_client, return_value):
+        test_client._session.get = return_value
+        # multi-param with bad data
+        assert len(test_client.datasets(
+            search_term=["description=description", "organisation_name=baddata"],
+            only_mine=False)) == 0
+
+    def test_find_datasets_like_name(self, test_client, return_value):
+        test_client._session.get = return_value
+        # 'like' test
+        assert len(test_client.datasets(
+            search_term=["name like Test"],
+            only_mine=True)) == 1
+
+    def test_find_datasets_by_id(self, test_client, return_value):
+        test_client._session.get = return_value
+        # 'like' test
+        assert len(test_client.datasets(
+            search_term=["id=5b01376e-975d-11e9-8832-7e5ef76d533f"],
+            only_mine=True)) == 1
+
+    def test_find_datasets_override_has_access_return_none(self, test_client, return_value):
+        test_client._session.get = return_value
+        # test override of param against kwarg of same (accomplish both ways)
+        assert len(test_client.datasets(
+            search_term=["has_access=True"],
+            only_mine=False)) == 0
+
+    def test_datasets_called_twice(self, test_client, package_request_index_v2,
+                                   dataset_request_index_v2):
         test_client._session.get.return_value.json.side_effect = [
-            dataset_request_v1,
-            {
-                'data': {
-                    'attributes': {
-                        'short_code': 'test',
-                        'location': {}
-                    },
-                    'id': 'test'
-                }
-            }
+            package_request_index_v2, dataset_request_index_v2
         ]
-
-        # calls in the same way as package
-        pp = test_client.datasets(search_term='', only_mine=False)
-        assert len(pp) == 1
-
-    def test_datasets_called_twice(self, test_client,
-                                   package_request,
-                                   package_request_v2,
-                                   dataset_request_index):
-        test_client._session.get.return_value.json.side_effect = [
-            package_request, package_request_v2, package_request,
-            dataset_request_index
-        ]
-
-        pp = test_client.packages(search_term='')
+        pp = test_client.packages(search_term='', only_mine=False)
 
         # This should work twice
         assert pp['Test Package'].datasets()
         assert pp['Test Package'].datasets()
 
-    def test_retrieve_instance_given_package_dataset(
-        self, test_client, package_request_v2,
-        package_request, dataset_request_index, instance_request
-    ):
+    def test_retrieve_instance_given_package_dataset(self, test_client,
+                                                     package_request_index_v2,
+                                                     dataset_request_index_v2,
+                                                     instance_request_v1
+                                                     ):
         test_client._session.get.return_value.json.side_effect = [
-            package_request, package_request_v2,
-            package_request, dataset_request_index, instance_request
+            package_request_index_v2,
+            dataset_request_index_v2, instance_request_v1,
         ]
 
-        pp = test_client.packages(search_term='')
+        pp = test_client.packages(search_term='', only_mine=False)
         ds = pp['Test Package'].datasets()
-        d = ds['Test DataSet']
+        d = ds['TestDataset']
         instances = list(d.instances.all())
-        assert(len(instances) == 1)
-        assert(instances[0].datafile_id == 1)
+        assert (len(instances) == 1)
+        assert (instances[0].datafile_id == 1)
